/*
 * @Description: 自定义弹出框请数据
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-05 15:50:59
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-06-28 11:31:37
 */
import {
  getWoFns,
  woGetSelectSuccess,
  woCustFn,
  woformSchema,
  woCfgformSchema,
  prodCfgformSchema,
  xxCfgformSchema,
} from './bizMesWo';
import { FormSchema } from '/@/components/Table';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
export const formSchema: FormSchema[] = [];
export async function custFunction<T = any>(
  e: any,
  fnName: string,
  type: string,
  ...args
): Promise<T> {
  switch (type) {
    case 'BIZ_MES_WO':
    case 'BIZ_MES_WO_Config':
      return getWoFns[fnName](e, args);
    // break;
    default:
      return new Promise((resolve, reject) => {
        try {
          (e) => {};
          resolve(true);
        } catch {
          reject(false);
        } finally {
          args[0][0]({ confirmLoading: false });
        }
      });
    // break;
  }
}

export function getFormSchema(type: string) {
  let _formSchema: FormSchema[] = [];
  switch (type) {
    case 'BIZ_MES_WO':
      _formSchema = woformSchema;
      break;
    case 'woinfo':
      _formSchema = woCfgformSchema;
      break;
    case 'prodinfo':
      _formSchema = prodCfgformSchema;
      break;
    case 'xxinfo':
      _formSchema = xxCfgformSchema;
      break;
    default:
      break;
      (e) => {};
  }
  return _formSchema;
}

/**
 * @description: 弹出选择框选择成功
 * @param {*} d
 * @param {*} u
 * @param {string} entityName
 * @return {*}
 */
export function GetSelectSuccess(d, u, entityName: string) {
  let data = {};
  switch (entityName) {
    case 'BIZ_MES_WO':
    case 'BIZ_MES_WO_Config':
      data = woGetSelectSuccess(d, u);
      break;
    default:
      data = {
        ITEM_CODE: d.values['val'],
      };
      break;
  }
  return data;
}

/**
 * @description: 打开弹出选择框
 * @return {*}
 */
export function OpenSelectItem(
  openItemModal: Fn,
  entityName: string,
  slotName: string,
  others: Fn[],
  ...args
) {
  switch (entityName) {
    case 'BIZ_MES_WO':
    case 'BIZ_MES_WO_Config': //根据带入的名称打开不同的实体列表
      woCustFn(openItemModal, slotName, others, args);
      break;
    default: //默认打开物料列表
      openItemModal(true, {
        title: '物料列表',
        schemas: [
          {
            field: 'ITEM_CODE',
            component: 'Input',
            label: '物料编码',
            colProps: {
              span: 12,
            },
          },
        ],
        ItemColumns: [
          {
            title: t('物料编码'),
            dataIndex: 'ITEM_CODE',
            resizable: true,
            sorter: true,
            width: 200,
          },
          {
            title: t('物料名称'),
            dataIndex: 'ITEM_NAME',
            resizable: true,
            sorter: true,
            width: 180,
          },
        ],
        tableName: 'BAS_ITEM',
        rowKey: 'ITEM_CODE',
        searchInfo: { TABLE_NAME: 'BAS_ITEM' }, //searchInfo: {TABLE_NAME: 'MES_CUSTOM_ACT', ACT_TYPE: routeConfig.currentAct.ACT_TYPE}
      });
      break;
  }
}

export const step1Schemas: FormSchema[] = [
  {
    field: 'CUST_CODE',
    component: 'Input',
    label: '客户编码',
    required: true,
    colProps: {
      span: 20,
    },
  },
  {
    field: '0',
    label: '',
    defaultValue: '',
    slot: 'add',
    colProps: {
      span: 4,
    },
  },
  {
    field: 'CUST_ID',
    component: 'Input',
    label: 'ID',
    required: true,
    colProps: {
      span: 20,
    },
    show: false,
  },
];

export const step2Schemas: FormSchema[] = [
  {
    field: 'ROT_CODE',
    component: 'Input',
    label: '工艺路线',
    required: true,
    colProps: {
      span: 20,
    },
  },
  {
    field: '0',
    label: '',
    defaultValue: '',
    slot: 'add',
    colProps: {
      span: 4,
    },
  },
  {
    field: 'ROT_ID',
    component: 'Input',
    label: 'ID',
    required: true,
    colProps: {
      span: 20,
    },
    show: false,
  },
];
